Cheshire3 Object Model - Index
==============================

.. _objects-index-api:

API
---

.. autoclass:: cheshire3.baseObjects.Index
   :members:

.. _objects-index-implementations:

Implementations
---------------

The following implementations are included in the distribution by default:

.. autoclass:: cheshire3.index.SimpleIndex

.. autoclass:: cheshire3.index.ProximityIndex

.. autoclass:: cheshire3.index.XmlIndex

.. autoclass:: cheshire3.index.XmlProximityIndex

.. autoclass:: cheshire3.index.RangeIndex

.. autoclass:: cheshire3.index.BitmapIndex

.. autoclass:: cheshire3.index.RecordIdentifierIndex

.. autoclass:: cheshire3.index.PassThroughIndex
